@@ -2,7 +2,7 @@
 
   Artificial frames
 
-  Copyright © 2016-9 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2016-21 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -205,5 +205,9 @@ bool Munipack::artificial(MuniProcess *action, MuniCmdLineParser& cmd)
       action->Write("CAT = '" + cname + "'");
   }
 
+  if( cmd.Found("galcat",&cname) ) {
+    action->Write("GALCAT = '" + cname + "'");
+  }
+
   return true;
 }
